from pyrf.gui import colors

GROUP_BOX_FONT = "QGroupBox { font-weight: bold; font-size: 12px} "
MARKER_LABEL_FONT = "background-color: rgb(%s, %s, %s); color: rgb(%s, %s, %s); font-size: 16px;" 
AXIS_LABEL_FONT = {'font-size': ' 12px', 'font-weight':'bold', 'color': colors.GREY_NUM}